You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by ud...@apache.org on 2016/09/13 20:21:07 UTC

[1/2] incubator-geode git commit: GEODE-420: Renaming of ssl-http-alias to ssl-web-alias

Repository: incubator-geode
Updated Branches:
  refs/heads/develop ee27d73c4 -> e76e2814a


GEODE-420: Renaming of ssl-http-alias to ssl-web-alias


Project: http://git-wip-us.apache.org/repos/asf/incubator-geode/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-geode/commit/bf54c902
Tree: http://git-wip-us.apache.org/repos/asf/incubator-geode/tree/bf54c902
Diff: http://git-wip-us.apache.org/repos/asf/incubator-geode/diff/bf54c902

Branch: refs/heads/develop
Commit: bf54c902774984070d632c5442f9abf42fda340b
Parents: a325d07
Author: Udo Kohlmeyer <uk...@pivotal.io>
Authored: Wed Sep 14 06:19:46 2016 +1000
Committer: Udo Kohlmeyer <uk...@pivotal.io>
Committed: Wed Sep 14 06:19:46 2016 +1000

----------------------------------------------------------------------
 .../web/controllers/RestAPIsWithSSLDUnitTest.java        |  9 ++++-----
 .../gemfire/distributed/ConfigurationProperties.java     | 10 +++++-----
 .../distributed/internal/AbstractDistributionConfig.java |  2 +-
 .../gemfire/distributed/internal/DistributionConfig.java | 11 +++++------
 .../internal/net/SSLConfigurationFactoryTest.java        |  6 +++---
 5 files changed, 18 insertions(+), 20 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/bf54c902/geode-assembly/src/test/java/com/gemstone/gemfire/rest/internal/web/controllers/RestAPIsWithSSLDUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-assembly/src/test/java/com/gemstone/gemfire/rest/internal/web/controllers/RestAPIsWithSSLDUnitTest.java b/geode-assembly/src/test/java/com/gemstone/gemfire/rest/internal/web/controllers/RestAPIsWithSSLDUnitTest.java
index 93efb7a..17c0dcf 100644
--- a/geode-assembly/src/test/java/com/gemstone/gemfire/rest/internal/web/controllers/RestAPIsWithSSLDUnitTest.java
+++ b/geode-assembly/src/test/java/com/gemstone/gemfire/rest/internal/web/controllers/RestAPIsWithSSLDUnitTest.java
@@ -70,7 +70,6 @@ import com.gemstone.gemfire.internal.AvailablePort;
 import com.gemstone.gemfire.internal.AvailablePortHelper;
 import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
 import com.gemstone.gemfire.internal.security.SecurableCommunicationChannel;
-import com.gemstone.gemfire.internal.security.SecurableComponent;
 import com.gemstone.gemfire.management.ManagementException;
 import com.gemstone.gemfire.test.dunit.Host;
 import com.gemstone.gemfire.test.dunit.IgnoredException;
@@ -324,7 +323,7 @@ public class RestAPIsWithSSLDUnitTest extends LocatorTestBase {
       sslPropertyConverter(sslProperties, props, SSL_REQUIRE_AUTHENTICATION, null);
       sslPropertyConverter(sslProperties, props, SSL_TRUSTSTORE, null);
       sslPropertyConverter(sslProperties, props, SSL_TRUSTSTORE_PASSWORD, null);
-      sslPropertyConverter(sslProperties, props, SSL_HTTP_SERVICE_ALIAS, null);
+      sslPropertyConverter(sslProperties, props, SSL_WEB_ALIAS, null);
       sslPropertyConverter(sslProperties, props, SSL_ENABLED_COMPONENTS, null);
       sslPropertyConverter(sslProperties, props, SSL_HTTP_SERVICE_REQUIRE_AUTHENTICATION, null);
       sslPropertyConverter(sslProperties, props, SSL_DEFAULT_ALIAS, null);
@@ -424,7 +423,7 @@ public class RestAPIsWithSSLDUnitTest extends LocatorTestBase {
       if (!StringUtils.isEmpty(properties.getProperty(INVALID_CLIENT_ALIAS))) {
         return properties.getProperty(INVALID_CLIENT_ALIAS);
       } else {
-        return properties.getProperty(SSL_HTTP_SERVICE_ALIAS);
+        return properties.getProperty(SSL_WEB_ALIAS);
       }
     }).build();
 
@@ -497,7 +496,7 @@ public class RestAPIsWithSSLDUnitTest extends LocatorTestBase {
     props.setProperty(SSL_TRUSTSTORE_PASSWORD, "password");
     props.setProperty(SSL_KEYSTORE_TYPE, "JKS");
     props.setProperty(SSL_ENABLED_COMPONENTS, SecurableCommunicationChannel.WEB.getConstant());
-    props.setProperty(SSL_HTTP_SERVICE_ALIAS, "httpservicekey");
+    props.setProperty(SSL_WEB_ALIAS, "httpservicekey");
     props.setProperty(SSL_HTTP_SERVICE_REQUIRE_AUTHENTICATION, "true");
     String restEndpoint = startInfraWithSSL(props, false);
     validateConnection(restEndpoint, "SSL", props);
@@ -514,7 +513,7 @@ public class RestAPIsWithSSLDUnitTest extends LocatorTestBase {
     props.setProperty(SSL_KEYSTORE_TYPE, "JKS");
     props.setProperty(SSL_ENABLED_COMPONENTS, SecurableCommunicationChannel.WEB.getConstant());
     props.setProperty(SSL_HTTP_SERVICE_REQUIRE_AUTHENTICATION, "true");
-    props.setProperty(SSL_HTTP_SERVICE_ALIAS, "httpservicekey");
+    props.setProperty(SSL_WEB_ALIAS, "httpservicekey");
     props.setProperty(INVALID_CLIENT_ALIAS, "someAlias");
     String restEndpoint = startInfraWithSSL(props, false);
     validateConnection(restEndpoint, "SSL", props);

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/bf54c902/geode-core/src/main/java/com/gemstone/gemfire/distributed/ConfigurationProperties.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/com/gemstone/gemfire/distributed/internal/AbstractDistributionConfig.java b/geode-core/src/main/java/com/gemstone/gemfire/distributed/internal/AbstractDistributionConfig.java
index 2a55a17..36f636d 100644
--- a/geode-core/src/main/java/com/gemstone/gemfire/distributed/internal/AbstractDistributionConfig.java
+++ b/geode-core/src/main/java/com/gemstone/gemfire/distributed/internal/AbstractDistributionConfig.java
@@ -946,7 +946,7 @@ public abstract class AbstractDistributionConfig extends AbstractConfig implemen
 
     m.put(GATEWAY_SSL_TRUSTSTORE_PASSWORD, "Password to unlock the keystore file (store password) specified by  javax.net.ssl.trustStore.");
 
-    m.put(SSL_HTTP_SERVICE_ALIAS, LocalizedStrings.AbstractDistributionConfig_HTTP_SERVICE_SSL_ALIAS_0.toLocalizedString(Boolean.valueOf(DEFAULT_SSL_ALIAS)));
+    m.put(SSL_WEB_ALIAS, LocalizedStrings.AbstractDistributionConfig_HTTP_SERVICE_SSL_ALIAS_0.toLocalizedString(Boolean.valueOf(DEFAULT_SSL_ALIAS)));
     m.put(HTTP_SERVICE_PORT, "If non zero, then the gemfire developer REST service will be deployed and started when the cache is created. Default value is 0.");
     m.put(HTTP_SERVICE_BIND_ADDRESS, "The address where gemfire developer REST service will listen for remote REST connections. Default is \"\" which causes the Rest service to listen on the host's default address.");
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/bf54c902/geode-core/src/main/java/com/gemstone/gemfire/distributed/internal/DistributionConfig.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/com/gemstone/gemfire/internal/net/SSLConfigurationFactoryTest.java b/geode-core/src/test/java/com/gemstone/gemfire/internal/net/SSLConfigurationFactoryTest.java
index 18729fd..c7f4d8f 100644
--- a/geode-core/src/test/java/com/gemstone/gemfire/internal/net/SSLConfigurationFactoryTest.java
+++ b/geode-core/src/test/java/com/gemstone/gemfire/internal/net/SSLConfigurationFactoryTest.java
@@ -127,7 +127,7 @@ public class SSLConfigurationFactoryTest extends JUnit4DistributedTestCase {
     properties.setProperty(SSL_TRUSTSTORE, "someKeyStore");
     properties.setProperty(SSL_TRUSTSTORE_PASSWORD, "keystorePassword");
     properties.setProperty(SSL_DEFAULT_ALIAS, "defaultAlias");
-    properties.setProperty(SSL_HTTP_SERVICE_ALIAS, "httpAlias");
+    properties.setProperty(SSL_WEB_ALIAS, "httpAlias");
     properties.setProperty(SSL_CIPHERS, "any");
     properties.setProperty(SSL_PROTOCOLS, "any");
     DistributionConfigImpl distributionConfig = new DistributionConfigImpl(properties);
@@ -147,7 +147,7 @@ public class SSLConfigurationFactoryTest extends JUnit4DistributedTestCase {
     properties.setProperty(SSL_TRUSTSTORE, "someKeyStore");
     properties.setProperty(SSL_TRUSTSTORE_PASSWORD, "keystorePassword");
     properties.setProperty(SSL_DEFAULT_ALIAS, "defaultAlias");
-    properties.setProperty(SSL_HTTP_SERVICE_ALIAS, "httpAlias");
+    properties.setProperty(SSL_WEB_ALIAS, "httpAlias");
     properties.setProperty(SSL_HTTP_SERVICE_REQUIRE_AUTHENTICATION, "true");
     properties.setProperty(SSL_CIPHERS, "any");
     properties.setProperty(SSL_PROTOCOLS, "any");
@@ -191,7 +191,7 @@ public class SSLConfigurationFactoryTest extends JUnit4DistributedTestCase {
       case GATEWAY:
         return getAliasForComponent(properties, SSL_GATEWAY_ALIAS);
       case WEB:
-        return getAliasForComponent(properties, SSL_HTTP_SERVICE_ALIAS);
+        return getAliasForComponent(properties, SSL_WEB_ALIAS);
       case JMX:
         return getAliasForComponent(properties, SSL_JMX_ALIAS);
       case LOCATOR:


[2/2] incubator-geode git commit: Merge branch 'develop' of https://git-wip-us.apache.org/repos/asf/incubator-geode into develop

Posted by ud...@apache.org.
Merge branch 'develop' of https://git-wip-us.apache.org/repos/asf/incubator-geode into develop


Project: http://git-wip-us.apache.org/repos/asf/incubator-geode/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-geode/commit/e76e2814
Tree: http://git-wip-us.apache.org/repos/asf/incubator-geode/tree/e76e2814
Diff: http://git-wip-us.apache.org/repos/asf/incubator-geode/diff/e76e2814

Branch: refs/heads/develop
Commit: e76e2814a0721546278311a330fb42f6943444d8
Parents: bf54c90 ee27d73
Author: Udo Kohlmeyer <uk...@pivotal.io>
Authored: Wed Sep 14 06:20:16 2016 +1000
Committer: Udo Kohlmeyer <uk...@pivotal.io>
Committed: Wed Sep 14 06:20:16 2016 +1000

----------------------------------------------------------------------
 .../cache/tier/sockets/CacheClientProxy.java    |   4 +-
 .../internal/security/GeodeSecurityUtil.java    | 549 -------------------
 .../security/IntegratedSecurityService.java     | 546 ++++++++++++++----
 .../internal/security/SecurityService.java      |  15 +-
 .../security/shiro/CustomAuthRealm.java         |   1 +
 .../management/internal/ManagementAgent.java    |   4 +-
 .../internal/cli/domain/DataCommandRequest.java |   6 +-
 .../cli/functions/DataCommandFunction.java      |  10 +-
 .../apache/geode/security/PostProcessor.java    |   3 +-
 .../security/templates/SamplePostProcessor.java |   3 +-
 .../security/GeodeSecurityUtilTest.java         | 288 ----------
 .../security/IntegratedSecurityServiceTest.java | 290 ++++++++++
 .../security/SecurityConfigIntegrationTest.java |  13 +-
 .../GeodeSecurityUtilCustomRealmJUnitTest.java  |  45 --
 .../GeodeSecurityUtilWithIniFileJUnitTest.java  | 143 -----
 ...atedSecurityServiceCustomRealmJUnitTest.java |  44 ++
 ...atedSecurityServiceWithIniFileJUnitTest.java | 147 +++++
 .../security/NoShowValue1PostProcessor.java     |   2 +-
 .../PDXGfshPostProcessorOnRemoteServerTest.java |   4 +-
 .../gemfire/security/PDXPostProcessor.java      |   3 +-
 .../security/PDXPostProcessorDUnitTest.java     |  10 +-
 .../codeAnalysis/sanctionedSerializables.txt    |   4 +-
 .../security/CQPDXPostProcessorDUnitTest.java   |   4 +-
 23 files changed, 958 insertions(+), 1180 deletions(-)
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/com/gemstone/gemfire/distributed/ConfigurationProperties.java b/geode-core/src/main/java/com/gemstone/gemfire/distributed/ConfigurationProperties.java
index 6db4142..fa0862f 100644
--- a/geode-core/src/main/java/com/gemstone/gemfire/distributed/ConfigurationProperties.java
+++ b/geode-core/src/main/java/com/gemstone/gemfire/distributed/ConfigurationProperties.java
@@ -601,15 +601,15 @@ public interface ConfigurationProperties {
    */
   String HTTP_SERVICE_PORT = "http-service-port";
   /**
    * The static String definition of the <i>"ssl-http-alias"</i> property
    * <a name="ssl-http-alias"/a></p>
    * <U>Description</U>: This property is to be used if a specific key is to be used for the SSL communications for the HTTP service.
    * </p>
    * <U><i>Optional</i></U>
    * <U>Default</U>: "" </p>
    * <U>Since</U>: Geode 1.0
    */
-  String SSL_HTTP_SERVICE_ALIAS = "ssl-http-alias";
+  String SSL_WEB_ALIAS = "ssl-web-alias";
   /**
    * The static String definition of the <i>"http-service-ssl-ciphers"</i> property
    * <a name="http-service-ssl-ciphers"/a></p>
@@ -632,7 +632,7 @@ public interface ConfigurationProperties {
    * </p>
    * <U>Default</U>: <code>false</code></p>
    * <U>Since</U>: GemFire 8.1
-   * @deprecated Since Geode 1.0 use {@link #SSL_ENABLED_COMPONENTS} with optional {@link #SSL_HTTP_SERVICE_ALIAS}
+   * @deprecated Since Geode 1.0 use {@link #SSL_ENABLED_COMPONENTS} with optional {@link #SSL_WEB_ALIAS}
    */
   @Deprecated
   String HTTP_SERVICE_SSL_ENABLED = "http-service-ssl-enabled";
@@ -1813,7 +1813,7 @@ public interface ConfigurationProperties {
    *
    * <U>Description</U>This property will be set when using multi-key keystores. This will define the alias that
    * the ssl connection factory would use when no alias has been set for the different component aliases.
-   * {@link #SSL_CLUSTER_ALIAS}, {@link #SSL_SERVER_ALIAS},{@link #SSL_LOCATOR_ALIAS},{@link #SSL_GATEWAY_ALIAS},{@link #SSL_JMX_ALIAS} , {@link #SSL_HTTP_SERVICE_ALIAS}
+   * {@link #SSL_CLUSTER_ALIAS}, {@link #SSL_SERVER_ALIAS},{@link #SSL_LOCATOR_ALIAS},{@link #SSL_GATEWAY_ALIAS},{@link #SSL_JMX_ALIAS} , {@link #SSL_WEB_ALIAS}
    * </p>
    * <U>Default</U>: ""</p>
    * <U>Since</U>: Geode 1.0

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/bf54c902/geode-core/src/main/java/com/gemstone/gemfire/distributed/internal/AbstractDistributionConfig.java
----------------------------------------------------------------------
@@ -601,15 +601,15 @@ public interface ConfigurationProperties {
   String HTTP_SERVICE_PORT = "http-service-port";
   /**
-   * The static String definition of the <i>"ssl-http-alias"</i> property
-   * <a name="ssl-http-alias"/a></p>
+   * The static String definition of the <i>"ssl-web-alias"</i> property
+   * <a name="ssl-web-alias"/a></p>
    * <U>Description</U>: This property is to be used if a specific key is to be used for the SSL communications for the HTTP service.
    * </p>
diff --git a/geode-core/src/main/java/com/gemstone/gemfire/distributed/internal/DistributionConfig.java b/geode-core/src/main/java/com/gemstone/gemfire/distributed/internal/DistributionConfig.java
index e90ac3e..27f2884 100644
--- a/geode-core/src/main/java/com/gemstone/gemfire/distributed/internal/DistributionConfig.java
+++ b/geode-core/src/main/java/com/gemstone/gemfire/distributed/internal/DistributionConfig.java
@@ -37,7 +37,6 @@ import com.gemstone.gemfire.internal.ConfigSource;
 import com.gemstone.gemfire.internal.logging.InternalLogWriter;
 import com.gemstone.gemfire.internal.logging.LogConfig;
 import com.gemstone.gemfire.internal.security.SecurableCommunicationChannel;
-import com.gemstone.gemfire.internal.security.SecurableComponent;
 import com.gemstone.gemfire.internal.tcp.Connection;
 import com.gemstone.gemfire.memcached.GemFireMemcachedServer;
 
@@ -4298,23 +4297,23 @@ public interface DistributionConfig extends Config, LogConfig {
    * property.
    * @since Geode 1.0
    */
-  @ConfigAttributeGetter(name = SSL_HTTP_SERVICE_ALIAS)
+  @ConfigAttributeGetter(name = SSL_WEB_ALIAS)
   String getHTTPServiceSSLAlias();
 
   /**
-   * Sets the value of the {@link ConfigurationProperties#SSL_HTTP_SERVICE_ALIAS}
+   * Sets the value of the {@link ConfigurationProperties#SSL_WEB_ALIAS}
    * property.
    * @since Geode 1.0
    */
-  @ConfigAttributeSetter(name = SSL_HTTP_SERVICE_ALIAS)
+  @ConfigAttributeSetter(name = SSL_WEB_ALIAS)
   void setHTTPServiceSSLAlias(String alias);
 
   /**
    * The name of the {@link ConfigurationProperties#SSL_HTTP_SERVICE_ALIAS} property
    * @since Geode 1.0
    */
   @ConfigAttribute(type = String.class)
-  String HTTP_SERVICE_SSL_ALIAS_NAME = SSL_HTTP_SERVICE_ALIAS;
+  String HTTP_SERVICE_SSL_ALIAS_NAME = SSL_WEB_ALIAS;
 
   /**
    * Returns the value of the {@link ConfigurationProperties#SSL_JMX_ALIAS}

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/bf54c902/geode-core/src/test/java/com/gemstone/gemfire/internal/net/SSLConfigurationFactoryTest.java
----------------------------------------------------------------------
@@ -4298,23 +4297,23 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
-   * The name of the {@link ConfigurationProperties#SSL_HTTP_SERVICE_ALIAS} property
+   * The name of the {@link ConfigurationProperties#SSL_WEB_ALIAS} property
    * @since Geode 1.0
    */